@@ -163,7 +163,7 @@ namespace BuildUtil
 				null);
 		public static readonly BuildSoftware vpnserver_linux_armeabi_ja =
 			new BuildSoftwareUnix(Software.vpnserver, 0, 0, "", CpuList.armeabi, OSList.Linux,
-				"linux-armeabi-32bit", false, "linux-armeabi-32bit-4.3.2", true,
+				"linux-armeabi-32bit", false, "linux-armeabi-32bit-4.3.2", false,
 				null);
 		public static readonly BuildSoftware vpnserver_linux_mipsel_ja =
 			new BuildSoftwareUnix(Software.vpnserver, 0, 0, "", CpuList.mipsel, OSList.Linux,
@@ -193,7 +193,7 @@ namespace BuildUtil
 				null);
 		public static readonly BuildSoftware vpnclient_linux_armeabi_ja =
 			new BuildSoftwareUnix(Software.vpnclient, 0, 0, "", CpuList.armeabi, OSList.Linux,
-				"linux-armeabi-32bit", false, "linux-armeabi-32bit-4.3.2", true,
+				"linux-armeabi-32bit", false, "linux-armeabi-32bit-4.3.2", false,
 				null);
 		public static readonly BuildSoftware vpnclient_linux_mipsel_ja =
 			new BuildSoftwareUnix(Software.vpnclient, 0, 0, "", CpuList.mipsel, OSList.Linux,
@@ -223,7 +223,7 @@ namespace BuildUtil
 				null);
 		public static readonly BuildSoftware vpnbridge_linux_armeabi_ja =
 			new BuildSoftwareUnix(Software.vpnbridge, 0, 0, "", CpuList.armeabi, OSList.Linux,
-				"linux-armeabi-32bit", false, "linux-armeabi-32bit-4.3.2", true,
+				"linux-armeabi-32bit", false, "linux-armeabi-32bit-4.3.2", false,
 				null);
 		public static readonly BuildSoftware vpnbridge_linux_mipsel_ja =
 			new BuildSoftwareUnix(Software.vpnbridge, 0, 0, "", CpuList.mipsel, OSList.Linux,
@@ -421,7 +421,7 @@ namespace BuildUtil
 	{
 		// Windows
 		public static readonly OS Windows = new OS("windows", "Windows",
-			"Windows 98 / 98 SE / ME / NT 4.0 SP6a / 2000 SP4 / XP SP2, SP3 / Vista SP1, SP2 / 7 SP1 / 8 / 8.1 / 10 / Server 2003 SP2 / Server 2008 SP1, SP2 / Hyper-V Server 2008 / Server 2008 R2 SP1 / Hyper-V Server 2008 R2 / Server 2012 / Hyper-V Server 2012 / Server 2012 R2 / Hyper-V Server 2012 R2 / Server 2016",
+			"Windows 98 / 98 SE / ME / NT 4.0 SP6a / 2000 SP4 / XP SP2, SP3 / Vista SP1, SP2 / 7 SP1 / 8 / 8.1 / 10 / Server 2003 SP2 / Server 2008 SP1, SP2 / Hyper-V Server 2008 / Server 2008 R2 SP1 / Hyper-V Server 2008 R2 / Server 2012 / Hyper-V Server 2012 / Server 2012 R2 / Hyper-V Server 2012 R2 / Server 2016 / Server 2019",
 			new Cpu[]
 			{
 				CpuList.intel,
